import 'package:flutter/material.dart';
import 'package:admost_flutter_plugin/admost.dart';
import 'package:admost_flutter_plugin/admost_interstitial.dart';
import 'package:admost_flutter_plugin/admost_rewarded.dart';
import 'package:admost_flutter_plugin/admost_ad_events.dart';
import 'package:admost_flutter_plugin/admost_banner.dart';
import 'package:admost_flutter_plugin/admost_banner_size.dart';
import 'dart:io';

void main() {
  WidgetsFlutterBinding.ensureInitialized();
  Admost.initialize(Platform.isIOS ? '15066ddc-9c18-492c-8185-bea7e4c7f88c' : '6cc8e89a-b52a-4e9a-bb8c-579f7ec538fe');
  runApp(MyApp());
}
/// This Widget is the main application widget.
class MyApp extends StatelessWidget {
  static const String _title = 'Flutter Code Sample';

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: _title,
      home: Scaffold(
        appBar: AppBar(title: const Text(_title)),
        body: MyHomePage(),
      ),
    );
  }
}

/// This is the stateless widget that the main application instantiates.
class MyHomePage extends StatefulWidget
{
  MyHomePage({Key key}) : super(key: key);

  @override
  _MyHomePageState createState() => _MyHomePageState();

}

class _MyHomePageState extends State<MyHomePage> {
  String interstitialText = 'Load Interstitial';
  String rewardedText = 'Load Rewarded';

  AdmostInterstitial interstitialAd;
  AdmostRewarded rewardAd;

  @override
  Widget build(BuildContext context) {
    return
      Padding(
        padding: EdgeInsets.all(10),
        child: Center(
          widthFactor: 2,
          heightFactor: 2,
          child: Column(
              children: <Widget>[
                Card(
                  child: InkWell(
                    splashColor: Colors.blue.withAlpha(30),
                    onTap: () async {
                      if (interstitialAd == null) {
                        interstitialAd = AdmostInterstitial(
                          zoneId: Platform.isIOS ? '39f74377-5682-436a-9338-9d1c4df410bd' : 'f99e409b-f9ab-4a2e-aa9a-4d143e6809ae',
                          listener: (AdmostAdEvent event,
                              Map<String, dynamic> args) {
                            if (event == AdmostAdEvent.loaded) {
                              interstitialText = 'Show Interstitial';
                              setState(() {
                                interstitialText;
                              });
                            }
                            if (event == AdmostAdEvent.dismissed) {
                              interstitialText = 'Load Interstitial';
                              setState(() {
                                interstitialText;
                              });
                            }
                            if (event == AdmostAdEvent.failedToLoad) {
                              // Start hoping they didn't just ban your account :)
                              print("Error code: ${args['errorCode']}");
                            }
                          },
                        );
                      }

                      if (await interstitialAd.isLoaded) {
                        interstitialAd.show();
                      } else {
                        interstitialAd.load();
                      }
                    },
                    child: Center(
                      widthFactor: 2,
                      heightFactor: 2,
                      child: Text(interstitialText),
                    ),
                  ),
                ),
                Card(
                  child: InkWell(
                    splashColor: Colors.blue.withAlpha(30),
                    onTap: () async {
                      if (rewardAd == null) {
                        rewardAd = AdmostRewarded(
                          zoneId: Platform.isIOS ? '2bdefd44-5269-4cbc-b93a-373b74a2f067' : '88cfcfd0-2f8c-4aba-9f36-cc0ac99ab140',
                          listener: (AdmostAdEvent event,
                              Map<String, dynamic> args) {
                            if (event == AdmostAdEvent.loaded) {
                              rewardedText = 'Show Rewarded';
                              setState(() {
                                rewardedText;
                              });
                            } else if (event == AdmostAdEvent.dismissed) {
                              rewardedText = 'Load Rewarded';
                              setState(() {
                                rewardedText;
                              });
                            } else if (event == AdmostAdEvent.failedToLoad) {
                              // Start hoping they didn't just ban your account :)
                              print("Error code: ${args['errorCode']}");
                            } else if (event == AdmostAdEvent.completed) {
                              print("REWARDED");
                            }
                          },
                        );
                      }

                      if (await rewardAd.isLoaded) {
                        rewardAd.show();
                      } else {
                        rewardAd.load();
                      }
                    },
                    child: Center(
                      widthFactor: 2,
                      heightFactor: 2,
                      child: Text(rewardedText),
                    ),
                  ),
                ),
                Card(
                    child:
                    AdmostBanner(
                      adUnitId: Platform.isIOS ? "b4009772-de04-42c4-bbaa-c18da9e4a1ab" : '9fb970db-7d96-4ef2-ac8c-d88ec22270ff',
                      adSize: AdmostBannerSize.LEADERBOARD,
                      listener: (AdmostAdEvent event,
                          Map<String, dynamic> args) {
                        if (event == AdmostAdEvent.loaded) {
                          print("ADMOST Ad Loaded");
                        }
                        if (event == AdmostAdEvent.clicked) {
                          print("ADMOST Ad clicked");
                        }
                        if (event == AdmostAdEvent.failedToLoad) {
                          print("Error code: ${args['errorCode']}");
                        }
                      },
                    )
                )
              ]
          ),

        ),
      );
  }

}