//
//  AdmostInterstitialPlugin.m
//  admost_flutter_plugin
//
//  Created by Mehmet Karagöz on 6.12.2019.
//

#import "AdmostInterstitialPlugin.h"
#import "AdmostInterstitialDelegate.h"
#import <AMRSDK/AMRSDK.h>

@implementation AdmostInterstitialPlugin {
    NSMutableDictionary <NSString*, AMRInterstitial*> *_interstitials;
    NSMutableDictionary <NSString*, AdmostInterstitialDelegate*> *_delegates;
}

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    AdmostInterstitialPlugin *instance = [[AdmostInterstitialPlugin alloc] init];
    instance.pluginRegistrar = registrar;
    
    FlutterMethodChannel *defaultChannel = [FlutterMethodChannel methodChannelWithName:@"admost_flutter/interstitial"
                                                                       binaryMessenger:registrar.messenger];
    [registrar addMethodCallDelegate:instance channel:defaultChannel];
}

- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
    NSDictionary *args = (NSDictionary *)call.arguments;
    if (!args) return;
    int rID = args[@"id"] ? [args[@"id"] intValue] : 0;
    NSString *key = [NSString stringWithFormat:@"%@", @(rID)];
    NSString *zoneId = args[@"zoneId"];
    
    if (!_interstitials) {
        _interstitials = [NSMutableDictionary new];
    }
    
    if (!_delegates) {
        _delegates = [NSMutableDictionary new];
    }
    
    if ([call.method isEqualToString:@"setListener"]) {
        FlutterMethodChannel *channel = [FlutterMethodChannel methodChannelWithName:[NSString stringWithFormat:@"admost_flutter/interstitial_%@", @(rID)]
                                                                    binaryMessenger:self.pluginRegistrar.messenger];
        
        AMRInterstitial *interstitial = _interstitials[key];
        AdmostInterstitialDelegate *delegate = [AdmostInterstitialDelegate delegateWithChannel:channel];
        interstitial.delegate = delegate;
        [_delegates setObject:delegate forKey:key];
    } else if ([call.method isEqualToString:@"load"]) {
        AMRInterstitial *interstitial = [AMRInterstitial interstitialForZoneId:zoneId];
        [_interstitials setObject:interstitial forKey:key];
        [interstitial loadInterstitial];
        result(nil);
    } else if ([call.method isEqualToString:@"isLoaded"]) {
        if ([_interstitials objectForKey:key]) {
            result(@(_interstitials[key].isLoaded));
        } else {
            result(@(NO));
        }
    } else if ([call.method isEqualToString:@"show"]) {
        if ([_interstitials objectForKey:key]) {
            AMRInterstitial *intersitital = _interstitials[key];
            if (intersitital.isLoaded) {
                [intersitital showFromViewController:[UIApplication sharedApplication].keyWindow.rootViewController];
            }
        }
    } else if ([call.method isEqualToString:@"dispose"]) {
        [_interstitials removeObjectForKey:key];
        [_delegates removeObjectForKey:key];
    } else {
        result(FlutterMethodNotImplemented);
    }
}

@end
