//
//  AdmostRewardedVideoPlugin.m
//  admost_flutter_plugin
//
//  Created by Mehmet Karagöz on 9.12.2019.
//

#import "AdmostRewardedVideoPlugin.h"
#import "AdmostRewardedVideoDelegate.h"
#import <AMRSDK/AMRSDK.h>

@implementation AdmostRewardedVideoPlugin {
    NSMutableDictionary <NSString*, AMRRewardedVideo*> *_rewardedVideos;
    NSMutableDictionary <NSString*, AdmostRewardedVideoDelegate*> *_delegates;
}

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    AdmostRewardedVideoPlugin *instance = [[AdmostRewardedVideoPlugin alloc] init];
    instance.pluginRegistrar = registrar;
    
    FlutterMethodChannel *defaultChannel = [FlutterMethodChannel methodChannelWithName:@"admost_flutter/rewarded"
                                                                       binaryMessenger:registrar.messenger];
    [registrar addMethodCallDelegate:instance channel:defaultChannel];
}

- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
    NSDictionary *args = (NSDictionary *)call.arguments;
    if (!args) return;
    int rID = args[@"id"] ? [args[@"id"] intValue] : 0;
    NSString *key = [NSString stringWithFormat:@"%@", @(rID)];
    NSString *zoneId = args[@"zoneId"];
    
    if (!_rewardedVideos) {
        _rewardedVideos = [NSMutableDictionary new];
    }
    
    if (!_delegates) {
        _delegates = [NSMutableDictionary new];
    }
    
    if ([call.method isEqualToString:@"setListener"]) {
        FlutterMethodChannel *channel = [FlutterMethodChannel methodChannelWithName:[NSString stringWithFormat:@"admost_flutter/rewarded_%@", @(rID)]
                                                                    binaryMessenger:self.pluginRegistrar.messenger];
        AMRRewardedVideo *rewardedVideo = _rewardedVideos[key];
        AdmostRewardedVideoDelegate *delegate = [AdmostRewardedVideoDelegate delegateWithChannel:channel];
        rewardedVideo.delegate = delegate;
        [_delegates setObject:delegate forKey:key];
    } else if ([call.method isEqualToString:@"load"]) {
        AMRRewardedVideo *rewardedVideo = [AMRRewardedVideo rewardedVideoForZoneId:zoneId];
        [_rewardedVideos setObject:rewardedVideo forKey:key];
        [rewardedVideo loadRewardedVideo];
        result(nil);
    } else if ([call.method isEqualToString:@"isLoaded"]) {
        if ([_rewardedVideos objectForKey:key]) {
            result(@(_rewardedVideos[key].isLoaded));
        } else {
            result(@(NO));
        }
    } else if ([call.method isEqualToString:@"show"]) {
        if ([_rewardedVideos objectForKey:key]) {
            AMRRewardedVideo *rewardedVideo = _rewardedVideos[key];
            if (rewardedVideo.isLoaded) {
                [rewardedVideo showFromViewController:[UIApplication sharedApplication].keyWindow.rootViewController];
            }
        }
    } else if ([call.method isEqualToString:@"dispose"]) {
        [_rewardedVideos removeObjectForKey:key];
        [_delegates removeObjectForKey:key];
    } else {
        result(FlutterMethodNotImplemented);
    }
}

@end
